@@ -17,14 +17,16 @@
 
 """Craft Providers base package."""
 
-__version__ = "1.4.2"  # noqa: F401
+__version__ = "1.6.0"  # noqa: F401
 
 from .base import Base  # noqa: F401
 from .errors import ProviderError  # noqa: F401
 from .executor import Executor  # noqa: F401
+from .provider import Provider  # noqa: f401
 
 __all__ = [
     "Base",
     "Executor",
     "ProviderError",
+    "Provider",
 ]
