@@ -238,7 +238,10 @@ class LXC:  # pylint: disable=too-many-public-methods
             )
         except subprocess.CalledProcessError as error:
             raise LXDError(
-                brief=f"Failed to set config key {key!r} to {value!r} for instance {instance_name!r}.",
+                brief=(
+                    f"Failed to set config key {key!r} to {value!r}"
+                    f" for instance {instance_name!r}."
+                ),
                 details=errors.details_from_called_process_error(error),
             ) from error
 
@@ -370,7 +373,10 @@ class LXC:  # pylint: disable=too-many-public-methods
             )
         except subprocess.CalledProcessError as error:
             raise LXDError(
-                brief=f"Failed to pull file {source.as_posix()!r} from instance {instance_name!r}.",
+                brief=(
+                    f"Failed to pull file {source.as_posix()!r}"
+                    f" from instance {instance_name!r}."
+                ),
                 details=errors.details_from_called_process_error(error),
             ) from error
 
@@ -434,7 +440,10 @@ class LXC:  # pylint: disable=too-many-public-methods
             )
         except subprocess.CalledProcessError as error:
             raise LXDError(
-                brief=f"Failed to push file {source.as_posix()!r} to instance {instance_name!r}.",
+                brief=(
+                    f"Failed to push file {source.as_posix()!r}"
+                    f" to instance {instance_name!r}."
+                ),
                 details=errors.details_from_called_process_error(error),
             ) from error
 
